@@ -1,14 +1,14 @@
 #!/usr/bin/env python2.5
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2010 Benoî HERVIER
+# Copyright (c) 2010 Benoît HERVIER
 # Licenced under GPLv3
 
 """A simple Twitter client made with pyqt4"""
 
-from PySide.QtGui import *
-from PySide.QtCore import *
-from PySide.QtMaemo5 import *
+from PyQt4.QtGui import *
+from PyQt4.QtCore import *
+from PyQt4.QtMaemo5 import *
 
 import khweeteur
 import twitter
@@ -25,7 +25,7 @@ from nwmanager import NetworkManager
 import dbus.service
 import dbus.mainloop.qt
 
-__version__ = '0.0.15'
+__version__ = '0.0.16'
 AVATAR_CACHE_FOLDER = os.path.join(os.path.expanduser("~"),'.khweeteur','cache')
 CACHE_PATH = os.path.join(os.path.expanduser("~"), '.khweeteur')
 KHWEETEUR_TWITTER_CONSUMER_KEY = 'uhgjkoA2lggG4Rh0ggUeQ'
@@ -98,8 +98,8 @@ class KhweeteurWorker(QThread):
             self.refresh_search()
 
     def testCacheFolders(self):
-        if not os.path.isdir(os.path.dirname(CACHE_PATH)):
-            os.mkdir(os.path.dirname(CACHE_PATH))
+        if not os.path.isdir(CACHE_PATH):
+            os.mkdir(CACHE_PATH)
         if not os.path.isdir(AVATAR_CACHE_FOLDER):
             os.mkdir(AVATAR_CACHE_FOLDER)
         
@@ -118,11 +118,11 @@ class KhweeteurWorker(QThread):
         downloadProfileImage = self.downloadProfileImage
                         
         current_dt = time.mktime((datetime.datetime.now() - datetime.timedelta(days=14)).timetuple())
+        mlist = []
         try:
-            mlist = []
             avatars_url={}
-            if (self.settings.value("twitter_access_token_key")!=''): 
-                api = twitter.Api(input_encoding='utf-8',username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, access_token_key=str(self.settings.value("twitter_access_token_key")),access_token_secret=str(self.settings.value("twitter_access_token_secret")))
+            if (self.settings.value("twitter_access_token_key").toString()!=''): 
+                api = twitter.Api(input_encoding='utf-8',username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, access_token_key=str(self.settings.value("twitter_access_token_key").toString()),access_token_secret=str(self.settings.value("twitter_access_token_secret").toString()))
                 for status in api.GetSearch(unicode(self.search_keyword).encode('UTF-8')):
                     if status.created_at_in_seconds > current_dt:
                         downloadProfileImage(status)
@@ -132,8 +132,8 @@ class KhweeteurWorker(QThread):
             self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
 
         try:
-            if (self.settings.value("twitter_access_token_key")!=''): 
-                api = twitter.Api(base_url='http://identi.ca/api/', username=KHWEETEUR_IDENTICA_CONSUMER_KEY,password=KHWEETEUR_IDENTICA_CONSUMER_SECRET, access_token_key=str(self.settings.value("identica_access_token_key")),access_token_secret=str(self.settings.value("identica_access_token_secret")))
+            if (self.settings.value("twitter_access_token_key").toString()!=''): 
+                api = twitter.Api(base_url='http://identi.ca/api/', username=KHWEETEUR_IDENTICA_CONSUMER_KEY,password=KHWEETEUR_IDENTICA_CONSUMER_SECRET, access_token_key=str(self.settings.value("identica_access_token_key").toString()),access_token_secret=str(self.settings.value("identica_access_token_secret").toString()))
                 for status in api.GetSearch(unicode(self.search_keyword).encode('UTF-8'),per_page=50):
                     if status.created_at_in_seconds > current_dt:
                         downloadProfileImage(status)
@@ -142,21 +142,21 @@ class KhweeteurWorker(QThread):
             print 'Error during refresh : ',e.message
             self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
 
-            if ((self.settings.value("twitter_access_token_key")!='')) or ((self.settings.value("identica_access_token_key")!='')): 
-
-                mlist.sort()
-                self.emit(SIGNAL("newStatuses(PyQt_PyObject)"),mlist)
+        if len(mlist)>0:
+            mlist.sort()
+            self.emit(SIGNAL("newStatuses(PyQt_PyObject)"),mlist)
 
         
     def refresh(self):
         print 'Try to refresh'
         downloadProfileImage = self.downloadProfileImage
         current_dt = time.mktime((datetime.datetime.now() - datetime.timedelta(days=14)).timetuple())
+        mlist = []
+
         try:
-            mlist = []
             avatars_url={}
-            if (self.settings.value("twitter_access_token_key")!=''): 
-                api = twitter.Api(username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, access_token_key=str(self.settings.value("twitter_access_token_key")),access_token_secret=str(self.settings.value("twitter_access_token_secret")))
+            if (self.settings.value("twitter_access_token_key").toString()!=''): 
+                api = twitter.Api(username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, access_token_key=str(self.settings.value("twitter_access_token_key").toString()),access_token_secret=str(self.settings.value("twitter_access_token_secret").toString()))
                 for status in api.GetFriendsTimeline(count=100):
                     if status.created_at_in_seconds > current_dt:
                         downloadProfileImage(status)
@@ -180,8 +180,8 @@ class KhweeteurWorker(QThread):
             self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
 
         try:
-            if (self.settings.value("identica_access_token_key")!=''): 
-                api = twitter.Api(base_url='http://identi.ca/api/', username=KHWEETEUR_IDENTICA_CONSUMER_KEY,password=KHWEETEUR_IDENTICA_CONSUMER_SECRET, access_token_key=str(self.settings.value("identica_access_token_key")),access_token_secret=str(self.settings.value("identica_access_token_secret")))
+            if (self.settings.value("identica_access_token_key").toString()!=''): 
+                api = twitter.Api(base_url='http://identi.ca/api/', username=KHWEETEUR_IDENTICA_CONSUMER_KEY,password=KHWEETEUR_IDENTICA_CONSUMER_SECRET, access_token_key=str(self.settings.value("identica_access_token_key").toString()),access_token_secret=str(self.settings.value("identica_access_token_secret").toString()))
                 for status in api.GetFriendsTimeline(count=100):
                     if status.created_at_in_seconds > current_dt:
                         downloadProfileImage(status)
@@ -207,21 +207,10 @@ class KhweeteurWorker(QThread):
             print 'Error during refresh : ',e.message
             self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
 
-            if ((self.settings.value("twitter_access_token_key")!='')) or ((self.settings.value("identica_access_token_key")!='')): 
-
-                mlist.sort()
-
-                #DOwnload avatar & add tweet to the model
-#                for _,status in mlist:
-#                    self.downloadProfileImage(status)
-                    #We are now in a thread
-                self.emit(SIGNAL("newStatuses(PyQt_PyObject)"),mlist)
-
-#            KhweeteurNotification().info('Error occurs during refresh.')
-
-
-        print 'Refresh ended'
-
+        if len(mlist)>0:
+            mlist.sort()
+            self.emit(SIGNAL("newStatuses(PyQt_PyObject)"),mlist)
+            
 class KhweetsModel(QAbstractListModel):
     """ListModel : A simple list : Start_At,TweetId, Users Screen_name, Tweet Text, Profile Image"""
 
@@ -292,11 +281,12 @@ class KhweetsModel(QAbstractListModel):
                              variant.id,
                              variant.user.screen_name,
                              variant.text,
-                             variant.user.profile_image_url.replace('/','_'),
+                             variant.user.profile_image_url,
                              self.GetRelativeCreatedAt(variant.created_at_in_seconds),))
-#                        self._avatars[variant.user.profile_image_url] = QVariant(QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(variant.user.profile_image_url))))
+                    if variant.user.screen_name!=None:
                         self._avatars[variant.user.profile_image_url] = (QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(variant.user.profile_image_url.replace('/','_')))))
-#                             QVariant(QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(variant.user.profile_image_url))))))
+
+                    #                             QVariant(QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(variant.user.profile_image_url))))))
                     else:
                         self._items.insert(0,
                              (variant.created_at_in_seconds,
@@ -324,8 +314,9 @@ class KhweetsModel(QAbstractListModel):
                          variant.text,
                          variant.user.profile_image_url,
                          self.GetRelativeCreatedAt(variant.created_at_in_seconds),))
-                    self._avatars[variant.user.profile_image_url] = (QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(variant.user.profile_image_url))))
-#                    self._avatars[variant.user.profile_image_url] = QVariant(QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(variant.user.profile_image_url))))
+                    if variant.user.screen_name!=None:
+                        self._avatars[variant.user.profile_image_url] = (QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(variant.user.profile_image_url.replace('/','_')))))
+                                                                    
                 else:
                     self._items.insert(0,
                          (variant.created_at_in_seconds,
@@ -395,9 +386,10 @@ class KhweetsModel(QAbstractListModel):
                     self._items = self._items[:index]
                     break
             for item in self._items:
-#                self._avatars[item[4]] = QVariant(QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(item[4]))))
+                #self._avatars[item[4]] = QVariant(QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(item[4]))))
                 if item[4]!=None:
                     self._avatars[item[4]] = (QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(item[4].replace('/','_')))))
+ 
             self._items.sort()
             self._items.reverse()
             QObject.emit(self, SIGNAL("dataChanged(const QModelIndex&, const QModelIndex &)"), self.createIndex(0,0), self.createIndex(0,len(self._items)))
@@ -409,21 +401,17 @@ class KhweetsModel(QAbstractListModel):
                 status = status +'\n'+ self._items[index.row()][5]     
             if self.display_screenname:
                 status = self._items[index.row()][2]+ ' : ' + status            
-#            return QVariant(status)
-            return (status)
+            return QVariant(status)
         elif role == Qt.DecorationRole:            
             if self.display_avatar:
                 try:
                     return self._avatars[self._items[index.row()][4]]
                 except:
-#                    return QVariant()
-                    return None
+                    return QVariant()
             else:
- #               return QVariant()
-                return None
+                return QVariant()
         else:
-#            return QVariant()
-            return None
+            return QVariant()
 
 class KhweetsView(QListView):
     def __init__(self,parent=None):
@@ -450,7 +438,7 @@ class KhweeteurAbout(QMainWindow):
         awidget.setMinimumSize(480,700)
         awidget.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
         aboutScrollArea.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
-        scroller = aboutScrollArea.property("kineticScroller") #.toPyObject()
+        scroller = aboutScrollArea.property("kineticScroller").toPyObject()
         scroller.setEnabled(True)
 
         aboutLayout = QVBoxLayout(awidget)
@@ -494,39 +482,12 @@ class KhweeteurPref(QMainWindow):
         self.loadPrefs()
 
     def loadPrefs(self):
-#        self.refresh_value.setValue(self.settings.value("refreshInterval").toInt()[0])
-#        self.displayUser_value.setCheckState(self.settings.value("displayUser").toInt()[0])
-#        self.displayAvatar_value.setCheckState(self.settings.value("displayAvatar").toInt()[0])
-#        self.displayTimestamp_value.setCheckState(self.settings.value("displayTimestamp").toInt()[0])
-#        self.useNotification_value.setCheckState(self.settings.value("useNotification").toInt()[0])
-#        self.useSerialization_value.setCheckState(self.settings.value("useSerialization").toInt()[0])
-        #Pyside
-        try:
-            self.refresh_value.setValue(int(self.settings.value("refreshInterval")))
-            
-            if self.settings.value("displayUser")!='0':
-                self.displayUser_value.setCheckState(Qt.Checked)
-            else:
-                self.displayUser_value.setCheckState(Qt.Unchecked)
-            if self.settings.value("displayAvatar")!='0':
-                self.displayAvatar_value.setCheckState(Qt.Checked)
-            else:
-                self.displayAvatar_value.setCheckState(Qt.Unchecked)
-            if self.settings.value("displayTimestamp")!='0':
-                self.displayTimestamp_value.setCheckState(Qt.Checked)
-            else:
-                self.displayTimestamp_value.setCheckState(Qt.Unchecked)
-            if self.settings.value("useNotification")!='0':
-                self.useNotification_value.setCheckState(Qt.Checked)
-            else:
-                self.useNotification_value.setCheckState(Qt.Unchecked)
-            if self.settings.value("useSerialization")!='0':
-                self.useSerialization_value.setCheckState(Qt.Checked)
-            else:
-                self.useSerialization_value.setCheckState(Qt.Unchecked)
-                
-        except:
-            KhweeteurNotification().info('Old pref format detected return to default')
+        self.refresh_value.setValue(self.settings.value("refreshInterval").toInt()[0])
+        self.displayUser_value.setCheckState(self.settings.value("displayUser").toInt()[0])
+        self.displayAvatar_value.setCheckState(self.settings.value("displayAvatar").toInt()[0])
+        self.displayTimestamp_value.setCheckState(self.settings.value("displayTimestamp").toInt()[0])
+        self.useNotification_value.setCheckState(self.settings.value("useNotification").toInt()[0])
+        self.useSerialization_value.setCheckState(self.settings.value("useSerialization").toInt()[0])
 
     def savePrefs(self):
         self.settings.setValue('refreshInterval',self.refresh_value.value())
@@ -541,7 +502,7 @@ class KhweeteurPref(QMainWindow):
         self.savePrefs()
 
     def request_twitter_access_or_clear(self):
-        if self.settings.value('twitter_access_token')=='true':
+        if self.settings.value('twitter_access_token').toBool():
             self.settings.setValue('twitter_access_token_key',QString())
             self.settings.setValue('twitter_access_token_secret',QString())
             self.settings.setValue('twitter_access_token',False)
@@ -600,8 +561,7 @@ class KhweeteurPref(QMainWindow):
                 
     def request_identica_access_or_clear(self):
 
-
-        if self.settings.value('identica_access_token')=='true':
+        if self.settings.value('identica_access_token').toBool():
             self.settings.setValue('identica_access_token_key',QString())
             self.settings.setValue('identica_access_token_secret',QString())
             self.settings.setValue('identica_access_token',False)
@@ -667,19 +627,19 @@ class KhweeteurPref(QMainWindow):
         self.aWidget.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
         self.scrollArea.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
         self.scrollArea.setWidget(self.aWidget)
-        scroller = self.scrollArea.property("kineticScroller") #.toPyObject()
+        scroller = self.scrollArea.property("kineticScroller").toPyObject()
         scroller.setEnabled(True)
         self._main_layout = QGridLayout(self.aWidget)
 
         self._main_layout.addWidget(QLabel('Authorizations :'),0,0)
-        if self.settings.value('twitter_access_token')=='true':
+        if self.settings.value('twitter_access_token').toBool():
             self.twitter_value = QPushButton('Clear Twitter Auth')
         else:
             self.twitter_value = QPushButton('Auth on Twitter')
         self._main_layout.addWidget(self.twitter_value,0,1)
         self.connect(self.twitter_value,SIGNAL('clicked()'),self.request_twitter_access_or_clear)
 
-        if self.settings.value('identica_access_token')=='true':
+        if self.settings.value('identica_access_token').toBool():
             self.identica_value = QPushButton('Clear Identi.ca Auth')
         else:
             self.identica_value = QPushButton('Auth on Identi.ca')
@@ -742,25 +702,16 @@ class KhweeteurWin(QMainWindow):
         self.setupMain()
 
         self.worker = None
-        print 'Pyside debug:',self.settings.value("displayUser")
-#        self.tweetsModel.display_screenname = self.settings.value("displayUser").toBool()
-#        self.tweetsModel.display_timestamp = self.settings.value("displayTimestamp").toBool()
-#        self.tweetsModel.display_avatar = self.settings.value("displayAvatar").toBool()
-        #Pyside
-        self.tweetsModel.display_screenname = (self.settings.value("displayUser")!='0')
-        self.tweetsModel.display_timestamp = (self.settings.value("displayTimestamp")!='0')
-        self.tweetsModel.display_avatar = (self.settings.value("displayAvatar")!='0')
-        print 'DEBUG Pyside displayAvatar: ',self.settings.value("displayAvatar")
+        self.tweetsModel.display_screenname = self.settings.value("displayUser").toBool()
+        self.tweetsModel.display_timestamp = self.settings.value("displayTimestamp").toBool()
+        self.tweetsModel.display_avatar = self.settings.value("displayAvatar").toBool()
         self.nw = NetworkManager(self.refresh_timeline)
         self.notifications = KhweeteurNotification()
 
         self.timer = QTimer()
         self.connect(self.timer, SIGNAL("timeout()"), self.timed_refresh)
-#        if (self.settings.value("refreshInterval").toInt()[0]>0):
-#            self.timer.start(self.settings.value("refreshInterval").toInt()[0]*60*1000)
-        #Pyside
-        if (int(self.settings.value("refreshInterval"))>0):
-            self.timer.start(int(self.settings.value("refreshInterval"))*60*1000)
+        if (self.settings.value("refreshInterval").toInt()[0]>0):
+            self.timer.start(self.settings.value("refreshInterval").toInt()[0]*60*1000)
 
         if self.search_keyword == None:
             self.open_saved_search()
@@ -794,8 +745,7 @@ class KhweeteurWin(QMainWindow):
         self.tb_text = QLineEdit()
         self.tb_text_replyid = 0
         self.tb_text_replytext = ''
-        #Pyside
-#        self.tb_text.enabledChange(True)
+        self.tb_text.enabledChange(True)
         self.toolbar.addWidget(self.tb_text)
 
         self.tb_charCounter = QLabel('140')
@@ -835,10 +785,10 @@ class KhweeteurWin(QMainWindow):
                 tweetid = self.tweetsModel._items[index.row()][1]
                 print 'DEBUG Retweet:',tweetid
                 try:
-                    if self.settings.value("twitter_access_token_key")!='':     
+                    if self.settings.value("twitter_access_token_key").toString()!='':     
                         api = twitter.Api(username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, 
-                                          access_token_key=str(self.settings.value("twitter_access_token_key")),
-                                          access_token_secret=str(self.settings.value("twitter_access_token_secret")))
+                                          access_token_key=str(self.settings.value("twitter_access_token_key").toString()),
+                                          access_token_secret=str(self.settings.value("twitter_access_token_secret").toString()))
                         api.PostRetweet(tweetid)
                         self.notifications.info('Retweet send to Twitter')
                 except (twitter.TwitterError,StandardError),e:
@@ -849,11 +799,11 @@ class KhweeteurWin(QMainWindow):
                         self.notifications.warn('Retweet to twitter failed : '+str(e))
                         print e                     
                 try:
-                    if self.settings.value("identica_access_token_key")!='': 
+                    if self.settings.value("identica_access_token_key").toString()!='': 
                         api = twitter.Api(base_url='http://identi.ca/api/',username=KHWEETEUR_IDENTICA_CONSUMER_KEY,
                                           password=KHWEETEUR_IDENTICA_CONSUMER_SECRET,
-                                          access_token_key=str(self.settings.value("identica_access_token_key")),
-                                          access_token_secret=str(self.settings.value("identica_access_token_secret")))    
+                                          access_token_key=str(self.settings.value("identica_access_token_key").toString()),
+                                          access_token_secret=str(self.settings.value("identica_access_token_secret").toString()))    
                         api.PostRetweet(tweetid)
                         self.notifications.info('Retweet send to Identi.ca')
                 except (twitter.TwitterError,StandardError),e:
@@ -871,23 +821,23 @@ class KhweeteurWin(QMainWindow):
                 if status_text.startswith(self.tb_text_replytext):
                     self.tb_text_replyid = 0
                     
-                if self.settings.value("twitter_access_token_key")!='':     
+                if self.settings.value("twitter_access_token_key").toString()!='':     
                     api = twitter.Api(
                                       username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, 
-                                      access_token_key=str(self.settings.value("twitter_access_token_key")),
-                                      access_token_secret=str(self.settings.value("twitter_access_token_secret")))
-                    if (self.settings.value('useSerialization')!='0'):
+                                      access_token_key=str(self.settings.value("twitter_access_token_key").toString()),
+                                      access_token_secret=str(self.settings.value("twitter_access_token_secret").toString()))
+                    if self.settings.value('useSerialization').toBool():
                         status = api.PostSerializedUpdates(status_text,in_reply_to_status_id=self.tb_text_replyid)
                     else:
                         status = api.PostUpdate(status_text,in_reply_to_status_id=self.tb_text_replyid)
                     self.notifications.info('Tweet send to Twitter')
 
-                if self.settings.value("identica_access_token_key")!='':     
+                if self.settings.value("identica_access_token_key").toString()!='':     
                     api = twitter.Api(base_url='http://identi.ca/api/',username=KHWEETEUR_IDENTICA_CONSUMER_KEY,
                                       password=KHWEETEUR_IDENTICA_CONSUMER_SECRET,
-                                      access_token_key=str(self.settings.value("identica_access_token_key")),
-                                      access_token_secret=str(self.settings.value("identica_access_token_secret")))
-                    if(self.settings.value('useSerialization')!='0'):
+                                      access_token_key=str(self.settings.value("identica_access_token_key").toString()),
+                                      access_token_secret=str(self.settings.value("identica_access_token_secret").toString()))
+                    if self.settings.value('useSerialization').toBool():
                         status = api.PostSerializedUpdates(status_text,in_reply_to_status_id=self.tb_text_replyid)
                     else:
                         status = api.PostUpdate(status_text,in_reply_to_status_id=self.tb_text_replyid)
@@ -911,12 +861,12 @@ class KhweeteurWin(QMainWindow):
 #        if self.search_keyword == None:
         self.tweetsModel.serialize(self.search_keyword)
         counter=self.tweetsModel.getNewAndReset()
-        if (counter>0) and (self.settings.value('useNotification')!='0') and not (self.isActiveWindow()):
+        if (counter>0) and (self.settings.value('useNotification').toBool()) and not (self.isActiveWindow()):
             self.notifications.notify('Khweeteur',str(counter)+' new tweet(s)',count=counter)
         self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,False)
 
     def do_refresh_now(self):
-        #print type(self.settings.value('useNotification')),self.settings.value('useNotification')
+        print type(self.settings.value('useNotification').toString()),self.settings.value('useNotification').toString()
         self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,True)
         self.worker = KhweeteurWorker(search_keyword=self.search_keyword)
         self.connect(self.worker, SIGNAL("newStatus(PyQt_PyObject)"), self.tweetsModel.addStatus)
@@ -945,16 +895,12 @@ class KhweeteurWin(QMainWindow):
             print 'isFinished()', self.worker.isFinished()
 
     def restartTimer(self):
-#        self.tweetsModel.display_screenname = self.settings.value("displayUser").toBool()
-#        self.tweetsModel.display_timestamp = self.settings.value("displayTimestamp").toBool()
-#        self.tweetsModel.display_avatar = self.settings.value("displayAvatar").toBool()
-        #Pyside
-        self.tweetsModel.display_screenname = (self.settings.value("displayUser")!='0')
-        self.tweetsModel.display_timestamp = (self.settings.value("displayTimestamp")!='0')
-        self.tweetsModel.display_avatar = (self.settings.value("displayAvatar")!='0')
+        self.tweetsModel.display_screenname = self.settings.value("displayUser").toBool()
+        self.tweetsModel.display_timestamp = self.settings.value("displayTimestamp").toBool()
+        self.tweetsModel.display_avatar = self.settings.value("displayAvatar").toBool()
         QObject.emit(self.tweetsModel, SIGNAL("dataChanged(const QModelIndex&, const QModelIndex &)"), self.tweetsModel.createIndex(0,0), self.tweetsModel.createIndex(0,len(self.tweetsModel._items)))
-        if (int(self.settings.value("refreshInterval"))>0):
-            self.timer.start(int(self.settings.value("refreshInterval"))*60*1000)
+        if (self.settings.value("refreshInterval").toInt()[0]>0):
+            self.timer.start(self.settings.value("refreshInterval").toInt()[0]*60*1000)
         else:
             self.timer.stop()
 
@@ -973,11 +919,8 @@ class KhweeteurWin(QMainWindow):
                 QKeySequence(self.tr("Ctrl+T", "Retweet")))
                 
         if self.search_keyword != None:
-    #        keywords = self.settings.value('savedSearch').toPyObject()
-            #Pyside
-            print 'Pyside debug',self.settings.value('savedSearch')
-            keywords = self.settings.value('savedSearch')
-            if keywords != None:
+            keywords = self.settings.value('savedSearch').toPyObject()
+            if (keywords != None):
                 if self.search_keyword in keywords:
                     fileMenu.addAction(self.tr("&Remove Search"), self.del_search)
                 else:
@@ -988,39 +931,40 @@ class KhweeteurWin(QMainWindow):
         fileMenu.addAction(self.tr("&About"), self.do_about)
 
     def del_search(self):
-#        keywords = self.settings.value('savedSearch').toPyObject()
-        #Pyside
-        print 'Pyside debug',self.settings.value('savedSearch')
-        keywords = self.settings.value('savedSearch')
-        if (keywords == None) or (type(keywords) != tuple):
+        keywords = self.settings.value('savedSearch').toPyObject()
+        if (keywords == None):
             keywords = []
+        elif (type(keywords)==QString):
+            if (self.search_keyword==keywords):
+                keywords = []
         else:
             index = keywords.indexOf(self.search_keyword)
             if index>=0:
                 keywords.removeAt(index)
-#        self.settings.setValue('savedSearch',QVariant(keywords))
-        self.settings.setValue('savedSearch',(keywords))
+        self.settings.setValue('savedSearch',QVariant(keywords))
         self.close()
                                 
     def save_search(self):
-#        keywords = self.settings.value('savedSearch').toPyObject()
-        #Pyside
-        print 'Pyside debug',self.settings.value('savedSearch')
-        keywords = self.settings.value('savedSearch')
-        if (keywords != None) and (type(keywords) == tuple):
+        keywords = self.settings.value('savedSearch').toPyObject()
+        print 'save_search:',keywords
+        if (keywords == None):
             keywords = []
+        elif (type(keywords)==QString):
+            keywords = [keywords,]
+        print 'save_search2:',keywords,type(keywords)
         keywords.append(self.search_keyword)
-#        self.settings.setValue('savedSearch',QVariant(keywords))
-        self.settings.setValue('savedSearch',(keywords))
+        print 'save_search3:',keywords,type(keywords)
+        self.settings.setValue('savedSearch',QVariant(keywords))
                                 
     def open_saved_search(self):
-#        keywords = self.settings.value('savedSearch').toPyObject()
-        #Pyside
-        keywords = self.settings.value('savedSearch')
-        print 'Pyside debug open_saved_search',type(keywords),self.settings.value('savedSearch')
-        if (keywords != None) and (type(keywords) == tuple):
+        keywords = self.settings.value('savedSearch').toPyObject()
+        print 'open_saved_search:',keywords
+        if (type(keywords)==QString):
+            keywords = [keywords,]
+
+        if (keywords != None):
             for keyword in keywords:
-                self.do_search(keyword)            
+                self.do_search(keyword)
     
     def open_search(self):
         search_keyword, ok = QInputDialog.getText(self, 'Search', 'Enter the search keyword(s) :')
